{{ fullname | escape | underline}}

.. automodule:: {{ fullname }}
{% block modules %}
{% if modules %}
.. rubric:: Modules

.. autosummary::
    :toctree:
    :recursive:
{% for item in modules %}
   {{ item }}
{%- endfor %}
{% endif %}
{% endblock %}
